pub struct MultiEditTool;Trait Implementations
Sourceimpl StaticTool for MultiEditTool
impl StaticTool for MultiEditTool
const DESCRIPTION: &'static str = "This is a tool for making multiple edits to a single file in one operation. Prefer this tool over the edit_file tool when you need to make multiple edits to the same file."
const REQUIRES_APPROVAL: bool = true
const REQUIRED_CAPABILITIES: Capabilities = Capabilities::WORKSPACE
type Params = MultiEditParams
type Output = MultiEditResult
type Spec = MultiEditToolSpec
fn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
params: Self::Params,
ctx: &'life1 StaticToolContext,
) -> Pin<Box<dyn Future<Output = Result<Self::Output, StaticToolError<MultiEditError>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn schema() -> ToolSchemawhere
Self: Sized,