pub struct GrepTool;Trait Implementations
Sourceimpl StaticTool for GrepTool
impl StaticTool for GrepTool
const DESCRIPTION: &'static str = r#"Fast content search built on ripgrep for blazing performance at any scale. - Searches using regular expressions or literal strings - Supports regex syntax like "log.*Error", "function\\s+\\w+", etc. - If the pattern isn't valid regex, it automatically searches for the literal text - Filter files by name pattern with include parameter (e.g., "*.js", "*.{ts,tsx}") - Automatically respects .gitignore files - Returns matches as "filepath:line_number: line_content""#
const REQUIRES_APPROVAL: bool = false
const REQUIRED_CAPABILITIES: Capabilities = Capabilities::WORKSPACE
type Params = GrepParams
type Output = GrepResult
type Spec = GrepToolSpec
fn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
params: Self::Params,
ctx: &'life1 StaticToolContext,
) -> Pin<Box<dyn Future<Output = Result<Self::Output, StaticToolError<GrepError>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn schema() -> ToolSchemawhere
Self: Sized,